@@ -1,8 +1,6 @@
 /*
-    $Id: vcd_xml_rip.c,v 1.73 2011/03/17 21:26:34 rocky Exp $
-
+    Copyright (C) 2005-2006, 2018 Rocky Bernstein <rocky@gnu.org>
     Copyright (C) 2001, 2003, 2004, 2005 Herbert Valerio Riedel <hvr@gnu.org>
-    Copyright (C) 2005, 2006 Rocky Bernstein <rocky@panix.com>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -63,8 +61,6 @@
 
 #include <popt.h>
 
-static const char _rcsid[] = "$Id: vcd_xml_rip.c,v 1.73 2011/03/17 21:26:34 rocky Exp $";
-
 static int _verbose_flag = 0;
 static int _quiet_flag = 0;
 
@@ -81,10 +77,10 @@ _register_file (vcdxml_t *p_vcdxml, const char *pathname,
     {
     case _STAT_DIR:
 	{
-	  struct filesystem_t *p_fs 
+	  struct filesystem_t *p_fs
 	    = calloc(1, sizeof (struct filesystem_t));
 	  _cdio_list_append (p_vcdxml->filesystem, p_fs);
-	  
+
 	  p_fs->name = strdup (pathname);
 	}
       break;
@@ -103,7 +99,7 @@ _register_file (vcdxml_t *p_vcdxml, const char *pathname,
 	{
 	  char namebuf2[strlen (namebuf) + 2];
 	  int i;
-		
+
 	  namebuf2[0] = '_';
 
 	  for (i = 0; namebuf[i]; i++)
@@ -123,18 +119,18 @@ _register_file (vcdxml_t *p_vcdxml, const char *pathname,
 	if (p_fs->file_raw)
 	  {
 	    if (p_fs->size % ISO_BLOCKSIZE == 0)
-	      { 
+	      {
 		p_fs->size /= ISO_BLOCKSIZE;
 		p_fs->size *= M2RAW_SECTOR_SIZE;
 	      }
 	    else if (p_fs->size % M2RAW_SECTOR_SIZE == 0)
 	      vcd_warn ("detected wrong size calculation for form2 file `%s'; fixing up", namebuf);
-	    else 
+	    else
 	      vcd_error ("form2 file has invalid file size");
 	  }
       }
       break;
-      
+
     default:
       vcd_assert_not_reached ();
       break;
@@ -142,10 +138,10 @@ _register_file (vcdxml_t *p_vcdxml, const char *pathname,
 }
 
 static int
-_parse_isofs_r (vcdxml_t *p_vcdxml, CdIo_t *p_cdio, 
+_parse_isofs_r (vcdxml_t *p_vcdxml, CdIo_t *p_cdio,
 		const char pathname[])
-{ 
-  CdioList_t *entlist = iso9660_fs_readdir (p_cdio, pathname, true);
+{
+  CdioList_t *entlist = iso9660_fs_readdir (p_cdio, pathname);
   CdioListNode_t *entnode;
 
   if (entlist == NULL)
@@ -162,8 +158,8 @@ _parse_isofs_r (vcdxml_t *p_vcdxml, CdIo_t *p_cdio,
 
       if (NULL == statbuf)
 	return -1;
-      
-      if (!strcmp (_name, ".") 
+
+      if (!strcmp (_name, ".")
 	  || !strcmp (_name, "..")
 	  || !strcmp (_name, "MPEGAV")
 	  || !strcmp (_name, "MPEG2")
@@ -184,7 +180,7 @@ _parse_isofs_r (vcdxml_t *p_vcdxml, CdIo_t *p_cdio,
       }
     }
 
-  _cdio_list_free (entlist, true);
+  _cdio_list_free (entlist, true, NULL);
 
   return 0;
 }
@@ -313,7 +309,7 @@ _parse_entries (vcdxml_t *p_vcdxml, CdIo_t *p_cdio)
       track_t track = vcdinf_get_track(&entries, idx);
       bool newtrack = (track != ltrack);
       ltrack = track;
-      
+
       vcd_assert (extent >= CDIO_PREGAP_SECTORS);
       extent = cdio_lba_to_lsn(extent);
 
@@ -339,7 +335,7 @@ _parse_entries (vcdxml_t *p_vcdxml, CdIo_t *p_cdio)
 
 	  snprintf (buf, sizeof (buf), "entry-%3.3d", idx);
 	  p_new_sequence->default_entry_id = strdup (buf);
-	  
+
 	  _cdio_list_append (p_vcdxml->sequence_list, p_new_sequence);
 	}
       else
@@ -348,7 +344,7 @@ _parse_entries (vcdxml_t *p_vcdxml, CdIo_t *p_cdio)
 	  struct sequence_t *p_seq =
 	    _cdio_list_node_data (_cdio_list_end (p_vcdxml->sequence_list));
 
-	  struct entry_point_t *p_entry = 
+	  struct entry_point_t *p_entry =
 	    calloc(1, sizeof (struct entry_point_t));
 
 	  snprintf (buf, sizeof (buf), "entry-%3.3d", idx);
@@ -370,7 +366,7 @@ _xstrdup(const char *s)
 {
   if (s)
     return strdup (s);
-  
+
   return NULL;
 }
 
@@ -390,7 +386,7 @@ _pin2id (unsigned pin)
 {
   static char buf[80];
   vcdinfo_itemid_t itemid;
-  
+
   vcdinfo_classify_itemid (pin, &itemid);
 
   switch(itemid.type) {
@@ -419,14 +415,14 @@ _ofs2id (unsigned offset, const pbc_ctx_t *_ctx)
   static char buf[80];
   unsigned sl_num = 0, el_num = 0, pl_num = 0;
   vcdinfo_offset_t *ofs = NULL;
-  
+
   if (offset == PSD_OFS_DISABLED)
     return NULL;
 
   _CDIO_LIST_FOREACH (node, _ctx->offset_list)
     {
       ofs = _cdio_list_node_data (node);
-	
+
       switch (ofs->type)
 	{
 	case PSD_TYPE_PLAY_LIST:
@@ -506,19 +502,19 @@ _pbc_node_read (const pbc_ctx_t *_ctx, unsigned offset)
       p_pbc = vcd_pbc_new (PBC_PLAYLIST);
       {
 	const PsdPlayListDescriptor_t *d = (const void *) _buf;
-	p_pbc->prev_id = _xstrdup (_ofs2id (vcdinf_pld_get_prev_offset(d), 
+	p_pbc->prev_id = _xstrdup (_ofs2id (vcdinf_pld_get_prev_offset(d),
 					   _ctx));
 	p_pbc->next_id = _xstrdup (_ofs2id (vcdinf_pld_get_next_offset(d),
 					   _ctx));
 	p_pbc->retn_id = _xstrdup (_ofs2id (vcdinf_pld_get_return_offset(d),
 					   _ctx));
-	
+
 	p_pbc->playing_time = (double) (vcdinf_get_play_time(d)) / 15.0;
 	p_pbc->wait_time       = vcdinf_get_wait_time(d);
 	p_pbc->auto_pause_time = vcdinf_get_autowait_time(d);
 
 	for (n = 0; n < vcdinf_pld_get_noi(d); n++) {
-	  _cdio_list_append (p_pbc->item_id_list, 
+	  _cdio_list_append (p_pbc->item_id_list,
 			    _xstrdup(_pin2id(vcdinf_pld_get_play_item(d,n)
 					     )));
 	  }
@@ -531,9 +527,9 @@ _pbc_node_read (const pbc_ctx_t *_ctx, unsigned offset)
       {
 	const PsdSelectionListDescriptor_t *d = (const void *) _buf;
 	p_pbc->bsn = vcdinf_get_bsn(d);
-	p_pbc->prev_id = _xstrdup (_ofs2id (vcdinf_psd_get_prev_offset(d), 
+	p_pbc->prev_id = _xstrdup (_ofs2id (vcdinf_psd_get_prev_offset(d),
 					   _ctx));
-	p_pbc->next_id = _xstrdup (_ofs2id (vcdinf_psd_get_next_offset(d), 
+	p_pbc->next_id = _xstrdup (_ofs2id (vcdinf_psd_get_next_offset(d),
 					   _ctx));
 	p_pbc->retn_id = _xstrdup (_ofs2id (vcdinf_psd_get_return_offset(d),
 					   _ctx));
@@ -562,7 +558,7 @@ _pbc_node_read (const pbc_ctx_t *_ctx, unsigned offset)
 	    break;
 	  }
 
-	p_pbc->timeout_id   = _xstrdup (_ofs2id (vcdinf_get_timeout_offset(d), 
+	p_pbc->timeout_id   = _xstrdup (_ofs2id (vcdinf_get_timeout_offset(d),
 						_ctx));
 	p_pbc->timeout_time = vcdinf_get_timeout_time (d);
 	p_pbc->jump_delayed = vcdinf_has_jump_delay(d);
@@ -571,7 +567,7 @@ _pbc_node_read (const pbc_ctx_t *_ctx, unsigned offset)
 
 	for (n = 0; n < vcdinf_get_num_selections(d); n++)
 	  {
-	    _cdio_list_append (p_pbc->select_id_list, 
+	    _cdio_list_append (p_pbc->select_id_list,
 			      _xstrdup(_ofs2id(vcdinf_psd_get_offset(d,n),
 					       _ctx)));
 	  }
@@ -579,7 +575,7 @@ _pbc_node_read (const pbc_ctx_t *_ctx, unsigned offset)
 	if (d->type == PSD_TYPE_EXT_SELECTION_LIST
 	    || d->flags.SelectionAreaFlag)
 	  {
-	    PsdSelectionListDescriptorExtended_t *d2 = 
+	    PsdSelectionListDescriptorExtended_t *d2 =
 	      (void *) &d->ofs[d->nos];
 
 	    p_pbc->prev_area = calloc(1, sizeof (pbc_area_t));
@@ -601,7 +597,7 @@ _pbc_node_read (const pbc_ctx_t *_ctx, unsigned offset)
 		_cdio_list_append (p_pbc->select_area_list, p_area);
 	      }
 
-	    vcd_assert (_cdio_list_length (p_pbc->select_area_list) 
+	    vcd_assert (_cdio_list_length (p_pbc->select_area_list)
 			== _cdio_list_length (p_pbc->select_id_list));
 	  }
       }
@@ -611,10 +607,10 @@ _pbc_node_read (const pbc_ctx_t *_ctx, unsigned offset)
       p_pbc = vcd_pbc_new (PBC_END);
       {
 	const PsdEndListDescriptor_t *d = (const void *) _buf;
-	
+
 	p_pbc->next_disc = d->next_disc;
 	p_pbc->image_id = _xstrdup (_pin2id (uint16_from_be (d->change_pic)));
-      }      
+      }
       break;
 
     default:
@@ -632,7 +628,7 @@ _pbc_node_read (const pbc_ctx_t *_ctx, unsigned offset)
 }
 
 static void
-_visit_pbc (pbc_ctx_t *p_pbc_ctx, lid_t lid, unsigned int offset, 
+_visit_pbc (pbc_ctx_t *p_pbc_ctx, lid_t lid, unsigned int offset,
 	    bool in_lot)
 {
   CdioListNode_t *node;
@@ -683,7 +679,7 @@ _visit_pbc (pbc_ctx_t *p_pbc_ctx, lid_t lid, unsigned int offset,
              */
             ofs->lid = lid;
           }
-          
+
           return; /* already been there... */
         }
     }
@@ -700,13 +696,13 @@ _visit_pbc (pbc_ctx_t *p_pbc_ctx, lid_t lid, unsigned int offset,
     case PSD_TYPE_PLAY_LIST:
       _cdio_list_append (p_pbc_ctx->offset_list, ofs);
       {
-        const PsdPlayListDescriptor_t *d = 
+        const PsdPlayListDescriptor_t *d =
 	  (const void *) (p_pbc_ctx->psd + _rofs);
         const lid_t lid = vcdinf_pld_get_lid(d);
 
         if (!ofs->lid)
           ofs->lid = lid;
-        else 
+        else
           if (ofs->lid != lid)
             vcd_warn ("LOT entry assigned LID %d, but descriptor has LID %d",
                       ofs->lid, lid);
@@ -729,7 +725,7 @@ _visit_pbc (pbc_ctx_t *p_pbc_ctx, lid_t lid, unsigned int offset,
 
         if (!ofs->lid)
           ofs->lid = lid;
-        else 
+        else
           if (ofs->lid != lid)
             vcd_warn ("LOT entry assigned LID %d, but descriptor has LID %d",
                       ofs->lid, lid);
@@ -742,7 +738,7 @@ _visit_pbc (pbc_ctx_t *p_pbc_ctx, lid_t lid, unsigned int offset,
 
         for (idx = 0; idx < vcdinf_get_num_selections(d); idx++)
           _visit_pbc (p_pbc_ctx, 0, vcdinf_psd_get_offset (d, idx), false);
-        
+
       }
       break;
 
@@ -768,8 +764,8 @@ _visit_lot (pbc_ctx_t *p_pbc_ctx)
     if ((tmp = vcdinf_get_lot_offset(lot, n)) != PSD_OFS_DISABLED)
       _visit_pbc (p_pbc_ctx, n + 1, tmp, true);
 
-  _vcd_list_sort (p_pbc_ctx->offset_list, 
-		  (_cdio_list_cmp_func) vcdinf_lid_t_cmp);
+  _vcd_list_sort (p_pbc_ctx->offset_list,
+		  (_cdio_list_cmp_func_t) vcdinf_lid_t_cmp);
 }
 
 static int
@@ -798,7 +794,7 @@ _parse_pbc (vcdxml_t *p_vcdxml, CdIo_t *p_cdio, bool no_ext_psd)
 	extended = true;
 	_lot_vcd_sector = statbuf->lsn;
 	vcd_assert (statbuf->size == ISO_BLOCKSIZE * LOT_VCD_SIZE);
-      }  
+      }
 
       free(statbuf);
       if (extended &&
@@ -817,9 +813,9 @@ _parse_pbc (vcdxml_t *p_vcdxml, CdIo_t *p_cdio, bool no_ext_psd)
   else {
     if (extended)
       vcd_info ("ignoring detected extended VCD2.0 PBC files");
-    
+
     _pbc_ctx.extended = false;
-    
+
     _lot_vcd_sector = LOT_VCD_SECTOR;
     _psd_vcd_sector = PSD_VCD_SECTOR;
     _psd_size = p_vcdxml->info.psd_size;
@@ -832,16 +828,16 @@ _parse_pbc (vcdxml_t *p_vcdxml, CdIo_t *p_cdio, bool no_ext_psd)
   _pbc_ctx.offset_list = _cdio_list_new ();
 
   /* read in LOT */
-  
+
   _pbc_ctx.lot = calloc(1, ISO_BLOCKSIZE * LOT_VCD_SIZE);
-  
-  if (cdio_read_mode2_sectors (p_cdio, _pbc_ctx.lot, _lot_vcd_sector, false, 
+
+  if (cdio_read_mode2_sectors (p_cdio, _pbc_ctx.lot, _lot_vcd_sector, false,
 			       LOT_VCD_SIZE)) {
-    _cdio_list_free (_pbc_ctx.offset_list, true);
+    _cdio_list_free (_pbc_ctx.offset_list, true, NULL);
     free(_pbc_ctx.lot);
     return -1;
   }
-  
+
 
   /* read in PSD */
 
@@ -853,7 +849,7 @@ _parse_pbc (vcdxml_t *p_vcdxml, CdIo_t *p_cdio, bool no_ext_psd)
     rc = -1;
     goto free_and_return;
   }
-  
+
 
   /* traverse it */
 
@@ -865,23 +861,23 @@ _parse_pbc (vcdxml_t *p_vcdxml, CdIo_t *p_cdio, bool no_ext_psd)
       pbc_t *_pbc;
 
       vcd_assert (ofs->offset != PSD_OFS_DISABLED);
-      
+
       if ((_pbc = _pbc_node_read (&_pbc_ctx, ofs->offset)))
 	_cdio_list_append (p_vcdxml->pbc_list, _pbc);
     }
 
  free_and_return:
-  _cdio_list_free (_pbc_ctx.offset_list, true);
+  _cdio_list_free (_pbc_ctx.offset_list, true, NULL);
   free(_pbc_ctx.lot);
   free(_pbc_ctx.psd);
-  return 0;
+  return rc;
 }
 
 static int
 _rip_isofs (vcdxml_t *p_vcdxml, CdIo_t *p_cdio)
 {
   CdioListNode_t *node;
-  
+
   _CDIO_LIST_FOREACH (node, p_vcdxml->filesystem)
     {
       struct filesystem_t *_fs = _cdio_list_node_data (node);
@@ -892,9 +888,9 @@ _rip_isofs (vcdxml_t *p_vcdxml, CdIo_t *p_cdio)
       if (!_fs->file_src)
 	continue;
 
-      vcd_info ("extracting %s to %s (lsn %u, size %u, raw %d)", 
+      vcd_info ("extracting %s to %s (lsn %u, size %u, raw %d)",
 		_fs->name, _fs->file_src,
-		(unsigned int) _fs->lsn, (unsigned int) _fs->size, 
+		(unsigned int) _fs->lsn, (unsigned int) _fs->size,
 		_fs->file_raw);
 
       if (!(outfd = fopen (_fs->file_src, "wb")))
@@ -927,7 +923,7 @@ _rip_isofs (vcdxml_t *p_vcdxml, CdIo_t *p_cdio)
 	perror ("ftruncate()");
 
       fclose (outfd);
-      
+
     }
 
   return 0;
@@ -956,7 +952,7 @@ _rip_segments (vcdxml_t *p_vcdxml, CdIo_t *p_cdio)
       memset (&mpeg_ctx, 0, sizeof (VcdMpegStreamCtx));
 
       vcd_info ("extracting %s... (start lsn %u, %d segments)",
-		p_seg->src, (unsigned int) start_extent, 
+		p_seg->src, (unsigned int) start_extent,
 		p_seg->segments_count);
 
       if (!(outfd = fopen (p_seg->src, "wb")))
@@ -977,8 +973,8 @@ _rip_segments (vcdxml_t *p_vcdxml, CdIo_t *p_cdio)
 
 	  memset (&buf, 0, sizeof (buf));
 	  cdio_read_mode2_sector (p_cdio, &buf, start_extent + n, true);
-	  
-	  if (!buf.subheader[0] 
+
+	  if (!buf.subheader[0]
               && !buf.subheader[1]
               && (buf.subheader[2] | SM_FORM2) == SM_FORM2
               && !buf.subheader[3])
@@ -1002,7 +998,7 @@ _rip_segments (vcdxml_t *p_vcdxml, CdIo_t *p_cdio)
 	  if (buf.subheader[2] & SM_TRIG)
 	    {
 	      double *_ap_ts = calloc(1, sizeof (double));
-	      
+
 	      vcd_debug ("autopause @%u (%f)", (unsigned int) n, last_pts);
 	      *_ap_ts = last_pts;
 
@@ -1060,19 +1056,19 @@ _rip_sequences (vcdxml_t *p_vcdxml, CdIo_t *p_cdio, int i_track)
 	vcd_info("Track %d selected, skipping track %d", i_track,counter-1);
 	continue;
       }
-	  
+
       if (i_track < 0 && -i_track==counter++) {
 	vcd_info("Skipping track %d", -i_track);
 	continue;
       }
-	  
+
       memset (&mpeg_ctx, 0, sizeof (VcdMpegStreamCtx));
 
       start_lsn = _seq->start_extent;
       end_lsn = _nseq ? _nseq->start_extent : cdio_get_disc_last_lsn (p_cdio);
 
       vcd_info ("extracting %s... (start lsn %lu (+%lu))",
-		_seq->src, (long unsigned int) start_lsn, 
+		_seq->src, (long unsigned int) start_lsn,
 		(long unsigned int) (end_lsn - start_lsn));
 
       if (!(outfd = fopen (_seq->src, "wb")))
@@ -1101,7 +1097,7 @@ _rip_sequences (vcdxml_t *p_vcdxml, CdIo_t *p_cdio, int i_track)
 	      const int secs_left = end_lsn - n;
 
 	      memset (buf, 0, sizeof (buf));
-	      cdio_read_mode2_sectors (p_cdio, buf, n, true, (secs_left > 15 
+	      cdio_read_mode2_sectors (p_cdio, buf, n, true, (secs_left > 15
 							   ? 15 : secs_left));
 	    }
 
@@ -1113,7 +1109,7 @@ _rip_sequences (vcdxml_t *p_vcdxml, CdIo_t *p_cdio, int i_track)
 	      vcd_warn ("encountered non-form2 sector -- leaving loop");
 	      break;
 	    }
-	  
+
 	  if (in_data)
 	    { /* end conditions... */
 	      if (!buf[buf_idx].subheader[0])
@@ -1124,7 +1120,7 @@ _rip_sequences (vcdxml_t *p_vcdxml, CdIo_t *p_cdio, int i_track)
 
 	      if (!(buf[buf_idx].subheader[2] & SM_REALT))
 		{
-		  vcd_debug ("subheader: no realtime data anymore @%u", 
+		  vcd_debug ("subheader: no realtime data anymore @%u",
 			     (unsigned int) n);
 		  break;
 		}
@@ -1150,7 +1146,7 @@ _rip_sequences (vcdxml_t *p_vcdxml, CdIo_t *p_cdio, int i_track)
 	    {
 	      CdioListNode_t *_node;
 
-	      vcd_mpeg_parse_packet (buf[buf_idx].data, M2F2_SECTOR_SIZE, 
+	      vcd_mpeg_parse_packet (buf[buf_idx].data, M2F2_SECTOR_SIZE,
 				     false, &mpeg_ctx);
 
 	      if (!mpeg_ctx.packet.zero)
@@ -1158,7 +1154,7 @@ _rip_sequences (vcdxml_t *p_vcdxml, CdIo_t *p_cdio, int i_track)
 
 	      if (!first_data && !mpeg_ctx.packet.zero)
 		first_data = n;
-	      
+
 	      if (mpeg_ctx.packet.has_pts)
 		{
 		  last_pts = mpeg_ctx.packet.pts;
@@ -1173,25 +1169,25 @@ _rip_sequences (vcdxml_t *p_vcdxml, CdIo_t *p_cdio, int i_track)
 		{
 		  double *_ap_ts = calloc(1, sizeof (double));
 
-		  vcd_debug ("autopause @%u (%f)", (unsigned int) n, 
+		  vcd_debug ("autopause @%u (%f)", (unsigned int) n,
 			     last_pts);
 		  *_ap_ts = last_pts;
 
 		  _cdio_list_append (_seq->autopause_list, _ap_ts);
 		}
-	      
+
 	      _CDIO_LIST_FOREACH (_node, _seq->entry_point_list)
 		{
 		  struct entry_point_t *_ep = _cdio_list_node_data (_node);
 
 		  if (_ep->extent == n)
 		    {
-		      vcd_debug ("entry point @%u (%f)", (unsigned int) n, 
+		      vcd_debug ("entry point @%u (%f)", (unsigned int) n,
 				 last_pts);
 		      _ep->timestamp = last_pts;
 		    }
 		}
-	      
+
 	      if (first_data)
 		{
 		  fwrite (buf[buf_idx].data, M2F2_SECTOR_SIZE, 1, outfd);
@@ -1204,14 +1200,14 @@ _rip_sequences (vcdxml_t *p_vcdxml, CdIo_t *p_cdio, int i_track)
 		}
 
 	    } /* if (in_data) */
-	  
+
 	  if (buf[buf_idx].subheader[2] & SM_EOF)
 	    {
 	      vcd_debug ("encountered subheader EOF @%u", (unsigned int) n);
 	      break;
 	    }
 	} /* for */
-      
+
       _progress.done = _progress.total;
       vcd_xml_read_progress_cb (&_progress, _seq->src);
 
@@ -1221,10 +1217,10 @@ _rip_sequences (vcdxml_t *p_vcdxml, CdIo_t *p_cdio, int i_track)
 
 	  if (n == end_lsn)
 	    vcd_debug ("stream till end of track");
-	  
+
 	  length = (1 + last_nonzero) - first_data;
 
-	  vcd_debug ("truncating file to %u packets", 
+	  vcd_debug ("truncating file to %u packets",
 		     (unsigned int) length);
 
 	  fflush (outfd);
@@ -1241,7 +1237,7 @@ _rip_sequences (vcdxml_t *p_vcdxml, CdIo_t *p_cdio, int i_track)
 static vcd_log_handler_t  gl_default_vcd_log_handler = NULL;
 static cdio_log_handler_t gl_default_cdio_log_handler = NULL;
 
-static void 
+static void
 _vcd_log_handler (vcd_log_level_t level, const char message[])
 {
   if (level == VCD_LOG_DEBUG && !_verbose_flag)
@@ -1249,7 +1245,7 @@ _vcd_log_handler (vcd_log_level_t level, const char message[])
 
   if (level == VCD_LOG_INFO && _quiet_flag)
     return;
-  
+
   gl_default_vcd_log_handler (level, message);
 }
 
@@ -1279,21 +1275,22 @@ main (int argc, const char *argv[])
   int _track_flag=0;
   int _x_track_flag=0;
 
-  enum { 
-    OP_SOURCE_UNDEF = DRIVER_UNKNOWN, 
+  typedef enum {
+    OP_SOURCE_UNDEF = DRIVER_UNKNOWN,
     OP_SOURCE_BINCUE= DRIVER_BINCUE,
     OP_SOURCE_NRG   = DRIVER_NRG,
     OP_SOURCE_CDRDAO= DRIVER_CDRDAO,
     OP_SOURCE_CDROM = DRIVER_DEVICE,
     OP_VERSION      = 20
-  } source_type = OP_SOURCE_UNDEF;
+  } option_t;
+  option_t source_type = OP_SOURCE_UNDEF;
 
   vcd_xml_progname = "vcdxrip";
 
   vcd_xml_init (&vcdxml);
 
   gl_default_vcd_log_handler  = vcd_log_set_handler (_vcd_log_handler);
-  gl_default_cdio_log_handler = 
+  gl_default_cdio_log_handler =
     cdio_log_set_handler ( (cdio_log_handler_t) _vcd_log_handler);
 
   {
@@ -1304,19 +1301,19 @@ main (int argc, const char *argv[])
        "specify xml file for output (default: '" DEFAULT_XML_FNAME "')",
        "FILE"},
 
-      {"bin-file", 'b', POPT_ARG_STRING|POPT_ARGFLAG_OPTIONAL, &source_name, 
+      {"bin-file", 'b', POPT_ARG_STRING|POPT_ARGFLAG_OPTIONAL, &source_name,
        OP_SOURCE_BINCUE,
-       "set image file as source (default: '" DEFAULT_IMG_FNAME "')", 
+       "set image file as source (default: '" DEFAULT_IMG_FNAME "')",
        "FILE"},
 
-      {"cue-file", 'c', POPT_ARG_STRING|POPT_ARGFLAG_OPTIONAL, &source_name, 
+      {"cue-file", 'c', POPT_ARG_STRING|POPT_ARGFLAG_OPTIONAL, &source_name,
        OP_SOURCE_BINCUE, "set \"cue\" CD-ROM disk image file as source", "FILE"},
 
-      {"nrg-file", 'N', POPT_ARG_STRING|POPT_ARGFLAG_OPTIONAL, &source_name, 
+      {"nrg-file", 'N', POPT_ARG_STRING|POPT_ARGFLAG_OPTIONAL, &source_name,
        OP_SOURCE_NRG, "set Nero CD-ROM disk image image file as source",
        "FILE"},
 
-      {"toc-file", '\0', POPT_ARG_STRING|POPT_ARGFLAG_OPTIONAL, &source_name, 
+      {"toc-file", '\0', POPT_ARG_STRING|POPT_ARGFLAG_OPTIONAL, &source_name,
        OP_SOURCE_CDRDAO, "set \"toc\" CD-ROM disk image file as source", "FILE"},
       {"cdrom-device", 'C', POPT_ARG_STRING|POPT_ARGFLAG_OPTIONAL, &source_name,
        OP_SOURCE_CDROM,"set CDROM device as source", "DEVICE"},
@@ -1324,8 +1321,8 @@ main (int argc, const char *argv[])
       {"sector-2336", '\0', POPT_ARG_NONE, &sector_2336_flag, 0,
        "use 2336 byte sector mode for image file"},
 
-      {"input", 'i', POPT_ARG_STRING|POPT_ARGFLAG_OPTIONAL, &source_name, 
-       OP_SOURCE_UNDEF, 
+      {"input", 'i', POPT_ARG_STRING|POPT_ARGFLAG_OPTIONAL, &source_name,
+       OP_SOURCE_UNDEF,
        "set source and determine if \"bin\" image or device", "FILE"},
 
       {"no-ext-psd", '\0', POPT_ARG_NONE, &no_ext_psd_flag, 0,
@@ -1346,29 +1343,29 @@ main (int argc, const char *argv[])
       {"nosegments", '\0', POPT_ARG_NONE, &noseg_flag, 0,
        "don't extract segment play items"},
 
-      {"progress", 'p', POPT_ARG_NONE, &_progress_flag, 0,  
-       "show progress"}, 
+      {"progress", 'p', POPT_ARG_NONE, &_progress_flag, 0,
+       "show progress"},
 
       { "track", 't', POPT_ARG_INT, &_track_flag, 0,
 	"rip only this track"},
-      
+
       { "notrack", 'T', POPT_ARG_INT, &_x_track_flag, 0,
 	"do not rip this track"},
-      
+
       { "filename-encoding", '\0', POPT_ARG_STRING, &vcd_xml_filename_charset, 0,
         "use given charset encoding for filenames instead of UTF8" },
 
-      {"verbose", 'v', POPT_ARG_NONE, &_verbose_flag, 0, 
+      {"verbose", 'v', POPT_ARG_NONE, &_verbose_flag, 0,
        "be verbose"},
-    
-      {"quiet", 'q', POPT_ARG_NONE, &_quiet_flag, 0, 
+
+      {"quiet", 'q', POPT_ARG_NONE, &_quiet_flag, 0,
        "show only critical messages"},
 
       {"gui", '\0', POPT_ARG_NONE, &_gui_flag, 0, "enable GUI mode"},
 
       {"version", 'V', POPT_ARG_NONE, NULL, OP_VERSION,
        "display version and copyright information and exit"},
-	   
+
       POPT_AUTOHELP {NULL, 0, 0, NULL, 0}
     };
 
@@ -1396,9 +1393,9 @@ main (int argc, const char *argv[])
 	    }
 	  source_type = opt;
 	  break;
-	
+
 	default:
-	  fprintf (stderr, "%s: %s\n", 
+	  fprintf (stderr, "%s: %s\n",
 		   poptBadOption(optCon, POPT_BADOPTION_NOALIAS),
 		   poptStrerror(opt));
 	  fprintf (stderr, "error while parsing command line - try --help\n");
@@ -1409,7 +1406,7 @@ main (int argc, const char *argv[])
 
     if (_verbose_flag && _quiet_flag)
       vcd_error ("I can't be both, quiet and verbose... either one or another ;-)");
-    
+
     if (poptGetArgs (optCon) != NULL)
       vcd_error ("Why are you giving me non-option arguments? -- try --help");
 
@@ -1435,9 +1432,9 @@ main (int argc, const char *argv[])
   /* If we don't specify a driver_id or a source_name, scan the
      system for a CD that contains a VCD.
    */
-  if (NULL == source_name && source_type == DRIVER_UNKNOWN) {
+  if (NULL == source_name && source_type == (option_t) DRIVER_UNKNOWN) {
     char **cd_drives=NULL;
-    cd_drives = cdio_get_devices_with_cap(NULL, 
+    cd_drives = cdio_get_devices_with_cap(NULL,
                 (CDIO_FS_ANAL_SVCD|CDIO_FS_ANAL_CVD|CDIO_FS_ANAL_VIDEOCD
                 |CDIO_FS_UNKNOWN),
                                           true);
@@ -1453,18 +1450,18 @@ main (int argc, const char *argv[])
     vcd_error ("Error determining place to read from.");
     exit (EXIT_FAILURE);
   }
-  
-  if (NULL == source_name) 
+
+  if (NULL == source_name)
     source_name = cdio_get_default_device(img_src);
 
-  vcdxml.comment = vcd_xml_dump_cl_comment (argc, argv, 
+  vcdxml.comment = vcd_xml_dump_cl_comment (argc, argv,
 					      nocommand_comment_flag);
 
   /* start with ISO9660 PVD */
   _parse_pvd (&vcdxml, img_src);
 
-  _parse_isofs (&vcdxml, img_src); 
-  
+  _parse_isofs (&vcdxml, img_src);
+
   /* needs to be parsed in order */
   _parse_info (&vcdxml, img_src);
   _parse_entries (&vcdxml, img_src);
@@ -1473,7 +1470,7 @@ main (int argc, const char *argv[])
   _parse_pbc (&vcdxml, img_src, no_ext_psd_flag);
 
   if (_x_track_flag) _track_flag = - _x_track_flag;
-  
+
   if (norip_flag || noseq_flag || noseg_flag || _track_flag) {
     vcd_warn ("Entry offsets inside sequence-items may incorrect...");
     vcd_warn ("and auto-pause locations might not be checked.");
